import sys
from PyQt5.QtWidgets import *
from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg as FigureCanvas
from matplotlib.figure import Figure
import matplotlib.pyplot as plt
import numpy as np

class App(QWidget):

    def __init__(self):
        super().__init__()
        self.title = 'Proba'
        self.left = 200
        self.top = 200
        self.width = 730
        self.height = 520
        self.initUI()
    
    def initUI(self):
        self.setWindowTitle(self.title)
        self.setGeometry(self.left, self.top, self.width, self.height)
        
        # Taster za crtanje sin(x)
        self.dugmeSinus = QPushButton('sin(x)', self)
        self.dugmeSinus.resize(100, 50)
        self.dugmeSinus.move(10, 10)
        self.dugmeSinus.clicked.connect(self.sinus1)
        
        # Taster za crtanje cos(x)
        self.dugmeKosinus = QPushButton('cos(x)', self)
        self.dugmeKosinus.resize(100, 50)
        self.dugmeKosinus.move(10, 70)
        self.dugmeKosinus.clicked.connect(self.kosinus1)  
        
        # Taster za crtanje sin(3x)
        self.dugmeExp = QPushButton('sin(3x)', self)
        self.dugmeExp.resize(100, 50)
        self.dugmeExp.move(10, 130)
        self.dugmeExp.clicked.connect(self.sinus3) 
        
        # Taster za crtanje cos(3x)
        self.dugmeKosinus = QPushButton('cos(3x)', self)
        self.dugmeKosinus.resize(100, 50)
        self.dugmeKosinus.move(10, 190)
        self.dugmeKosinus.clicked.connect(self.kosinus3)  
        
        # Dodavanje polja za unos teksta
        self.text_input = QLineEdit('1', self)
        self.text_input.resize(100, 50)
        self.text_input.move(10,250)
        
        # Dodavanje polja za prikaz teksta
        self.text_output = QLabel(' ', self)
        self.text_output.resize(100, 50)
        self.text_output.move(10,310) 
        
        # Dodavanje grafika
        self.grafik = PlotCanvas(self, width = 6, height = 5)
        self.grafik.move(120, 10)
        
        self.t = np.arange(0,10,0.01)
        
        self.show()
    
    def sinus1(self):
        A = float(self.text_input.text())
        self.grafik.plot(x = self.t, y = A*np.sin(self.t), naslov = 'sin(x)')
        self.text_output.setText(str(A) + 'sin(x)')
    def kosinus1(self):
        A = float(self.text_input.text())
        self.grafik.plot(x = self.t, y = A*np.cos(self.t), naslov = 'cos(x)')
        self.text_output.setText(str(A) + 'cos(x)')
    def sinus3(self):
        A = float(self.text_input.text())
        self.grafik.plot(x = self.t, y = A*np.sin(3*self.t), naslov = 'sin(x)')
        self.text_output.setText(str(A) + 'sin(3x)')
    def kosinus3(self):
        A = float(self.text_input.text())
        self.grafik.plot(x = self.t, y = A*np.cos(3*self.t), naslov = 'cos(x)')
        self.text_output.setText(str(A) + 'cos(3x)')
        
    
class PlotCanvas(FigureCanvas):

    def __init__(self, parent = None, width = 2, height = 2, dpi = 100):
        fig = Figure(figsize=(width, height), dpi=dpi)
        self.axes = fig.add_subplot(111)
        self.axes.grid()

        FigureCanvas.__init__(self, fig)
        self.setParent(parent)

        FigureCanvas.setSizePolicy(self,
                QSizePolicy.Expanding,
                QSizePolicy.Expanding)
        FigureCanvas.updateGeometry(self)
#        self.plot()


    def plot(self, x, y, naslov = ' ', tip = 'k-'):
        self.axes.cla()
        self.axes.grid()
        self.axes.plot(x, y, tip)
        self.axes.set_title(naslov)
        self.draw()
        
if __name__ == '__main__':
    app = QApplication(sys.argv)
    ex = App()
    app.exec_()